@@ -41,11 +41,9 @@ var upgradeCmd = &cobra.Command{
 		terminal.Init(env.Shell())
 		fmt.Print(terminal.StartProgress())
 
-		defer fmt.Print(terminal.StopProgress())
-
 		latest, err := upgrade.Latest(env)
 		if err != nil {
-			fmt.Printf("\n❌ %s\n\n", err)
+			fmt.Printf("\n❌ %s\n\n%s", err, terminal.StopProgress())
 			os.Exit(1)
 			return
 		}
@@ -59,19 +57,24 @@ var upgradeCmd = &cobra.Command{
 
 		version := fmt.Sprintf("v%s", build.Version)
 
-		if version == latest {
-			if !cfg.DisableNotice {
-				fmt.Print("\n✅ no new version available\n\n")
-			}
+		if version != latest {
+			executeUpgrade(latest)
 			return
 		}
 
-		executeUpgrade(latest)
+		message := terminal.StopProgress()
+
+		if !cfg.DisableNotice {
+			message += "\n✅ no new version available\n\n"
+		}
+
+		fmt.Print(message)
 	},
 }
 
 func executeUpgrade(latest string) {
 	err := upgrade.Run(latest)
+	fmt.Print(terminal.StopProgress())
 	if err == nil {
 		return
 	}
